@@ -8,7 +8,7 @@ import abc
 from django.conf import settings
 from six import with_metaclass
 
-from .utils import cached_property
+from m3_gar_client.utils import cached_property
 
 
 class Config(with_metaclass(abc.ABCMeta, object)):
