@@ -111,16 +111,18 @@ class Backend(BackendBase):
         """
         return get_address_object(obj_id, timeout)
 
-    def find_house(self, house_number, parent_id, timeout=None):
+    def find_house(self, house_number, parent_id, building_number, structure_number, timeout=None):
         """Возвращает информацию о здании по его номеру.
 
         :param unicode house_number: Номер дома.
         :param parent_id: ID родительского объекта.
+        :param unicode building_number: Номер корпуса.
+        :param unicode structure_number: Номер строения.
         :param float timeout: Timeout запросов к серверу ГАР в секундах.
 
         :rtype: m3_gar_client.data.House or NoneType
         """
-        return find_house(house_number, parent_id, timeout)
+        return find_house(house_number, parent_id, building_number, structure_number, timeout)
 
     def get_house(self, house_id, timeout=None):  # pylint: disable=signature-differs
         """Возвращает информацию о здании по его ID в ГАР.
