@@ -160,6 +160,13 @@ def _int(value):
         raise ValueError(value)
 
 
+def _bool(value):
+    try:
+        return bool(value if isinstance(value, bool) else bool(value))
+    except (TypeError, ValueError):
+        raise ValueError(value)
+
+
 def _int_or_none(value):
     return _int(value) if value else None
 
@@ -291,6 +298,11 @@ class AddressObject(ObjectBase):
             required=True,
             description='Краткое наименование типа объекта',
         ),
+        'type_full_name': FieldDescriptor(
+            data_type=_unicode,
+            required=True,
+            description='Полное наименование типа объекта',
+        ),
         'official_name': FieldDescriptor(
             data_type=_unicode_or_empty,
             required=False,
@@ -326,6 +338,11 @@ class AddressObject(ObjectBase):
             required=False,
             description='Полный адрес',
         ),
+        'has_children': FieldDescriptor(
+            data_type=_bool,
+            required=False,
+            description='Признак наличия потомков',
+        ),
         'region_code': FieldDescriptor(
             data_type=_int,
             required=True,
